Simple wave test in a sheared slab domain
=========================================

Uses the same field-aligned Clebsch coordinate system as most BOUT++ tokamak
simulations. See the coordinates manual for details.

Note: Here the only components of the coordinate system which are tested are
`g_22` (for `Grad_par`), and the twist shift angle.
